package witersen.dao;

import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.util.ArrayList;
import java.util.List;

import witersen.vo.Emp;

public class EmpDAOImpl implements IEmpDAO {

    private Connection conn = null;
    private PreparedStatement pstmt = null;

    public EmpDAOImpl(Connection conn) {
        this.conn = conn;
    }

    @Override
    public boolean doCreate(Emp emp) throws Exception {
        boolean flag = false;
        String sql = "insert into emp(empno,ename,job,hiredate,comm,imgUrl) values (?,?,?,?,?,?)";
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setInt(1, emp.getEmpno());
        this.pstmt.setString(2, emp.getEname());
        this.pstmt.setString(3, emp.getJob());
        this.pstmt.setDate(4, new java.sql.Date(emp.getHiredate().getTime()));
        this.pstmt.setFloat(5, emp.getComm());
        this.pstmt.setString(6, emp.getImgUrl());
        if (this.pstmt.executeUpdate() > 0) {
            flag = true;
        }
        this.pstmt.close();
        return flag;
    }

    @Override
    public Emp findById(int empno) throws Exception {
        Emp emp = null;
        String sql = "select empno,ename,job,hiredate,comm,imgUrl from emp where empno=?";
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setInt(1, empno);
        ResultSet rs = this.pstmt.executeQuery();
        if (rs.next()) {
            emp = new Emp();
            emp.setEmpno(rs.getInt(1));
            emp.setEname(rs.getString(2));
            emp.setJob(rs.getString(3));
            emp.setHiredate(rs.getDate(4));
            emp.setComm(rs.getFloat(5));
            emp.setImgUrl(rs.getString(6));
        }
        this.pstmt.close();
        return emp;
    }

    @Override
    public List<Emp> findAll(String keyWord, int pageSize, int current) throws Exception {
        int begin = pageSize * (current - 1);
        int count = pageSize;

        List<Emp> all = new ArrayList<Emp>(); // 定义集合
        String sql = "select empno,ename,job,hiredate,comm,imgUrl from emp where ename like ? limit ? , ?";
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setInt(2, begin);
        this.pstmt.setInt(3, count);
        this.pstmt.setString(1, "%" + keyWord + "%");
        ResultSet rs = this.pstmt.executeQuery();
        Emp emp = null;
        while (rs.next()) {
            emp = new Emp();
            emp.setEmpno(rs.getInt(1));
            emp.setEname(rs.getString(2));
            emp.setJob(rs.getString(3));
            emp.setHiredate(rs.getDate(4));
            emp.setComm(rs.getFloat(5));
            emp.setImgUrl(rs.getString(6));
            all.add(emp);
        }
        this.pstmt.close();
        return all;
    }

    @Override
    public int getTotalCount(String keyWord) throws Exception {
        String sql = "select count(*) from emp where ename like ?";
        int total = 0;
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setString(1, "%"+keyWord+"%");
        ResultSet rs = this.pstmt.executeQuery();
        while (rs.next()) {
            total = rs.getInt(1);
        }
        this.pstmt.close();
        return total;
    }

    @Override
    public boolean updateInfo(Emp emp) throws Exception {
        boolean flag = false;
        int id=-1;
        String sql = "select id from emp where empno = ?";
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setInt(1, emp.getEmpno());
        ResultSet rs = this.pstmt.executeQuery();
        while(rs.next()) {
            id = rs.getInt(1);
        }
        
        sql = "update emp set empno=?,ename=?,job=?,hiredate=?,comm=?,imgUrl=? where id=? ";
        this.pstmt = this.conn.prepareStatement(sql);
        this.pstmt.setInt(1, emp.getEmpno());
        this.pstmt.setString(2, emp.getEname());
        this.pstmt.setString(3, emp.getJob());
        this.pstmt.setDate(4, new java.sql.Date(emp.getHiredate().getTime()));
        this.pstmt.setFloat(5, emp.getComm());
        this.pstmt.setString(6, emp.getImgUrl());
        this.pstmt.setInt(7, id);
        if (this.pstmt.executeUpdate() > 0) {
            flag = true;
        }
        this.pstmt.close();
        return flag;
    }

}
